#!/bin/sh
# Check if AFS client is working
# Michael Tosch
#

PATH=/bin:/usr/bin:/usr/proc/bin:/usr/afs/bin:/usr/afsws/bin:/usr/afsw/bin:/opt/afssw/bin:/usr/sbin:/sbin
export PATH

case $1 in
"") afsroot=/afs;;
/*) afsroot=$1;;
*) echo "usage: $0 [AFSroot]"; exit 3;;
esac

if [ \! -d $afsroot ]
then
  echo "(OK) no $afsroot"
  exit 0
fi

# AFS mounts:
mounts=`mount -v | awk '$3==afsroot && $5~/[Aa][Ff][Ss]|lofs|bind/ {++cnt} END {print cnt}' afsroot="$afsroot"`

if [ -z "$mounts" ]
then
  echo "CRITICAL: AFS is not mounted on $afsroot"
  exit 2
fi

# contents check
contents=`echo "$afsroot"/*/*`
if [ "$contents" = "$afsroot/*/*" ]
then
  echo "WARNING: $afsroot mounted but empty"
  exit 1
fi

# AFS version:
ver=`fs -version 2>/dev/null | awk '{print $2}'`

echo "OK: AFS $ver, mounted on $afsroot"

